.. image:: https://raw.githubusercontent.com/aperezdc/omni/master/assets/omni-logo-full.png
   :alt: OMNI

============================================
Omniscient Multiple Networked Identification
============================================

.. image:: https://readthedocs.org/projects/omni/badge/?version=latest
   :target: https://omni.readthedocs.org/en/latest
   :alt: Documentation Status

.. image:: https://img.shields.io/travis/aperezdc/omni.svg?style=flat
   :target: https://travis-ci.org/aperezdc/omni
   :alt: Build Status

.. image:: https://img.shields.io/coveralls/aperezdc/omni/master.svg?style=flat
   :target: https://coveralls.io/r/aperezdc/omni?branch=master
   :alt: Code Coverage


Installation
============

The stable releases are uploaded to `PyPI <https://pypi.python.org>`_, so
you can install and upgrade using ``pip``::

  pip install omni

Alternatively, you can install development versions —at your own risk—
directly from the Git repository::

  pip install -e git://github.com/aperezdc/omni

Documentation
=============

The documetation for OMNI is available at:

  http://omni.readthedocs.org/en/latest/

.. important:: Note that the documentation is work-in-progress and
               for the moment it is lacking a lot of content.


Development
===========

If you want to contribute to OMNI, please use the usual GitHub workflow:

1. Clone the repository.
2. Hack on your clone of OMNI.
3. Send a pull request for review.

If you do not have programming skills, you can still contribute by
`reporting issues <https://github.com/aperezdc/omni/issues>`_ that you may
encounter.
